predict.lm2: Predict method for lm2 objects

View source: R/lm2.R

predict.lm2R Documentation

Predict method for lm2 objects

Description

Predict method for lm2 objects

Usage

## S3 method for class 'lm2'
predict(object, newdata, ...)

Arguments

object

An object of class lm2

newdata

An optional data frame in which to look for variables with which to predict. If omitted, the original model data is used.

...

Additional arguments passed to predict.lm_robust, including se.fit and interval.

Value

A vector of predicted values (or a list with fit and se.fit if se.fit = TRUE, or a matrix with fit, lwr, upr if interval is specified)


statuser documentation built on April 25, 2026, 5:06 p.m.