print.t.test2: Print method for t.test2 output

View source: R/print_t.test2.R

print.t.test2R Documentation

Print method for t.test2 output

Description

Print method for t.test2 output

Usage

## S3 method for class 't.test2'
print(x, ...)

Arguments

x

An object of class t.test2

...

Additional arguments passed to print

Value

Invisibly returns the input object x. Called for its side effect of printing a formatted t-test summary to the console, including means, confidence intervals, test statistics, p-values, sample sizes, and APA-formatted results.


statuser documentation built on April 25, 2026, 5:06 p.m.