Learn R Programming

statuser (version 0.1.9)

statuser-package: Stat Tools for End Users

Description

Basic and custom statistical tools designed with end users in mind. Functions have optimized defaults, produce decluttered and informative output that is self-explanatory, and generate publication-ready results in 1 line of code.

Arguments

Basic Stats (improved)

  • lm2: like lm(), with robust SE and much more informative output

  • t.test2: like t.test(), decluttered, and more informative output

  • table2: like table(), showing variable names, and with proportions & chi2 built in

  • desc_var: Descriptive statistics for variables (optional, by group(s))

Custom Stats (new)

  • twolines: Two-lines test for U-shapes (Simonsohn 2018)

Graphing

  • scatter.gam: Makes scatter plot for x & y, with fitted GAM line y=f(x)

  • plot_cdf: Plot empirical cumulative distribution functions (optional, by group)

  • plot_density: Plot density functions (optional, by group)

  • plot_freq: Plot frequency of observed values (optional, by group)

  • plot_gam: Plot fitted GAM values for a focal predictor

  • text2: like text() adding text-alignment and background color

Formatting

  • format_pvalue: Format p-values for display

  • message2: Print colored messages to console

  • resize_images: Resize images (SVG, PDF, EPS, JPG, PNG, etc.) to PNG with specified width

Miscellaneous

  • list2: Like list(), but unnamed objects are automatically named

  • convert_to_sql: Convert CSV files to SQL INSERT statements

  • clear: Clear environment, console, and all graphics devices

Author

Uri Simonsohn urisohn@gmail.com

References

Simonsohn, U. (2018). Two lines: A valid alternative to the invalid testing of U-shaped relationships with quadratic regressions. Advances in Methods and Practices in Psychological Science, 1(4), 538-555.

See Also