| validate_t.test2 | R Documentation |
Validates that a grouping variable exists and has exactly 2 levels for t-test.
validate_t.test2(
group_var_name,
data = NULL,
calling_env = parent.frame(),
data_name = NULL
)
group_var_name |
Character string. Name of the grouping variable (for error messages). |
data |
An optional data frame containing the variable. |
calling_env |
The environment in which to look for the variable if data is not provided. |
data_name |
Character string. Name of the data argument (for error messages). If NULL, will attempt to infer from the call. |
The validated grouping variable (numeric or factor vector). Stops execution with an error message if validation fails.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.